---
layout: "vault"
page_title: "Vault: vault_ad_access_credentials data source"
sidebar_current: "docs-vault-datasource-ad-access-credentials"
description: |-
  Reads Active Directory credentials from an AD secret backend in Vault
---

# vault\_ad\_access\_credentials

Reads Active Directory credentials from an AD secret backend in Vault.

~> **Important** All data retrieved from Vault will be
written in cleartext to state file generated by Terraform, will appear in
the console output when Terraform runs, and may be included in plan files
if secrets are interpolated into any resource attributes.
Protect these artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_ad_secret_backend" "config" {
    backend = "ad"
    binddn = "CN=Administrator,CN=Users,DC=corp,DC=example,DC=net"
    bindpass = "SuperSecretPassw0rd"
    url = "ldaps://ad"
    insecure_tls = "true"
    userdn = "CN=Users,DC=corp,DC=example,DC=net"
}

resource "vault_ad_secret_role" "bob" {
    backend = vault_ad_secret_backend.config.backend
    role = "bob"
    service_account_name = "Bob"
    ttl = 60
}

data "vault_ad_access_credentials" "creds" {
  backend = vault_ad_secret_backend.config.backend
  role    = vault_ad_secret_role.bob.role}
  depends_on = [vault_ad_secret_role.bob]
}
```

## Argument Reference

The following arguments are supported:

* `backend` - (Required) The path to the AD secret backend to
read credentials from, with no leading or trailing `/`s.

* `role` - (Required) The name of the AD secret backend role to read
credentials from, with no leading or trailing `/`s.

## Attributes Reference

In addition to the arguments above, the following attributes are exported:

* `current_password` - The current set password on the Active Directory service account.

* `last_password` - The current set password on the Active Directory service account, provided because AD is eventually consistent.

* `username` - The Active Directory service account username.
