---
layout: "vault"
page_title: "Vault: vault_identity_entity resource"
sidebar_current: "docs-vault-resource-identity-entity"
description: |-
  Creates an Identity Entity for Vault.
---

# vault\_identity\_entity

Creates an Identity Entity for Vault. The Identity secrets engine is the identity management solution for Vault. It internally maintains the clients who are recognized by Vault.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_identity_entity" "test" {
  name      = "tester1"
  policies  = ["test"]
  metadata  = {
    foo = "bar"
  }
}
```

## Argument Reference

The following arguments are supported:

* `name` - (Required) Name of the identity entity to create.

* `policies` - (Optional) A list of policies to apply to the entity.

* `metadata` - (Optional) A Map of additional metadata to associate with the user.

* `disabled` - (Optional) True/false Is this entity currently disabled. Defaults to `false`

* `external_policies` - (Optional) `false` by default. If set to `true`, this resource will ignore any policies return from Vault or specified in the resource. You can use [`vault_identity_entity_policies`](identity_entity_policies.html) to manage policies for this entity in a decoupled manner.

## Attributes Reference

* `id` - The `id` of the created entity.

## Import

Identity entity can be imported using the `id`, e.g.

```
$ terraform import vault_identity_entity.test "ae6f8ued-0f1a-9f6b-2915-1a2be20dc053"
```