---
layout: "vault"
page_title: "Vault: vault_rabbitmq_secret_backend_role resource"
sidebar_current: "docs-vault-resource-rabbitmq-secret-backend-role"
description: |-
  Creates a role on an RabbitMQ Secret Backend for Vault.
---

# vault\_rabbitmq\_secret\_backend\_role

Creates a role on an RabbitMQ Secret Backend for Vault. Roles are
used to map credentials to the policies that generated them.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_rabbitmq_secret_backend" "rabbitmq" {
  connection_uri = "https://....."
  username = "user"
  password = "password"
}

resource "vault_rabbitmq_secret_backend_role" "role" {
  backend = "${vault_rabbitmq_secret_backend.rabbitmq.path}"
  name    = "deploy"

  tags = "tag1,tag2"
  vhosts = "{\"/\": {\"configure\":\".*\", \"write\":\".*\", \"read\": \".*\"}}"
}
```

## Argument Reference

The following arguments are supported:

* `backend` - (Required) The path the RabbitMQ secret backend is mounted at,
with no leading or trailing `/`s.

* `name` - (Required) The name to identify this role within the backend.
Must be unique within the backend.

* `tags` - (Optional) Specifies a comma-separated RabbitMQ management tags.

* `vhosts` - (Optional) Specifies a map of virtual hosts to permissions.

## Attributes Reference

No additional attributes are exported by this resource.

## Import

RabbitMQ secret backend roles can be imported using the `path`, e.g.

```
$ terraform import vault_rabbitmq_secret_backend_role.role rabbitmq/roles/deploy
```
