---
layout: "vault"
page_title: "Vault: vault_terraform_cloud_secret_backend resource"
sidebar_current: "docs-vault-resource-terraform-cloud-secret-backend"
description: |-
  Creates a Terraform Cloud secret backend for Vault.
---

# vault\_terraform\_cloud\_secret\_backend

Creates a Terraform Cloud Secret Backend for Vault. Terraform Cloud secret backends
can then create Terraform Cloud tokens, once a role with the appropriate creds
has been added to the backend.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_terraform_cloud_secret_backend" "test" {
  path        = "terraform"
  description = "Manages the Terraform Cloud backend"
  token       = "V0idfhi2iksSDU234ucdbi2nidsi..."
}
```

## Argument Reference

The following arguments are supported:

* `token` - (Required) The Terraform Cloud management token this backend should 
  use to issue new tokens.

~> **Important** Because Vault does not support reading the configured
token back from the API, Terraform cannot detect and correct drift
on `token`. Changing the value, however, _will_ overwrite the previously stored values.

* `backend` - (Optional) The unique location this backend should be mounted at. Must not begin or end with a `/`. Defaults to `terraform`.

* `description` - (Optional) A human-friendly description for this backend.

* `default_lease_ttl_seconds` - (Optional) The default TTL for credentials issued by this backend.

* `max_lease_ttl_seconds` - (Optional) The maximum TTL that can be requested
for credentials issued by this backend.

## Attributes Reference

No additional attributes are exported by this resource.

## Import

Terraform Cloud secret backends can be imported using the `backend`, e.g.

```
$ terraform import vault_terraform_cloud_secret_backend.example terraform
```
